@@ -1,5 +1,5 @@
 package Games::LMSolve::Plank::Base;
-$Games::LMSolve::Plank::Base::VERSION = '0.10.0';
+$Games::LMSolve::Plank::Base::VERSION = '0.10.1';
 our $AUTHORITY = 'cpan:SHLOMIF';
 
 use strict;
@@ -340,6 +340,18 @@ sub enumerate_moves
 
     my @moves;
 
+    my %current;
+    my $serialize = sub {
+        return join"\t", @_;
+    };
+
+    foreach my $plank (@$plank_data)
+    {
+        $current{$serialize->(@$plank{qw(x y end_x end_y)})} =
+        $current{$serialize->(@$plank{qw(end_x end_y x y)})} =
+            1;
+    }
+
     for my $to_move_idx (0 .. $#$plank_data)
     {
         my $to_move = $plank_data->[$to_move_idx];
@@ -371,6 +383,12 @@ sub enumerate_moves
                     {
                         next;
                     }
+                    # Check that we're not moving one plank on top of the
+                    # other or itself.
+                    if (exists $current{$serialize->($x,$y,$other_x,$other_y)})
+                    {
+                        next DIR_LOOP;
+                    }
 
                     # Check if there is a stump at the other end-point
                     if (! $board->[$other_y]->[$other_x])
@@ -508,7 +526,7 @@ Games::LMSolve::Plank::Base - driver for solving the rectangular Plank puzzles
 
 =head1 VERSION
 
-version 0.10.0
+version 0.10.1
 
 =head1 SYNOPSIS
 
@@ -516,7 +534,7 @@ NA - should not be used directly.
 
 =head1 VERSION
 
-version 0.10.0
+version 0.10.1
 
 =head1 METHODS
 
